@@ -29,9 +29,7 @@ from nrel.hive.app import run
 from nrel.hive.config import HiveConfig
 from nrel.hive.dispatcher import *
 from nrel.hive.state.simulation_state.update.update import Update
-from nrel.hive.state.simulation_state.update.step_simulation import (
-    StepSimulation,
-)
+from nrel.hive.state.simulation_state.update.step_simulation import StepSimulation
 
 
 def package_root() -> Path:
