@@ -2,15 +2,17 @@ from __future__ import annotations
 
 from abc import abstractmethod, ABC
 from dataclasses import dataclass
+from typing import Any, Dict
 
 from nrel.hive.model.roadnetwork.route import Route
+from nrel.hive.util.units import Unit
 
 
 @dataclass(frozen=True)
 class PowertrainMixin:
-    speed_units: str
-    distance_units: str
-    energy_units: str
+    speed_units: Unit
+    distance_units: Unit
+    energy_units: Unit
 
 
 class PowertrainABC(ABC):
@@ -28,6 +30,13 @@ class PowertrainABC(ABC):
         :return: energy cost of this route
         """
 
+    @classmethod
+    @abstractmethod
+    def from_data(cls, data: Dict[str, Any]) -> Powertrain:
+        """
+        Build a Powertrain from a data dictionary
+        """
+
 
 class Powertrain(PowertrainMixin, PowertrainABC):
     """"""
