@@ -10,9 +10,7 @@ from nrel.hive.util import wkt
 if TYPE_CHECKING:
     from nrel.hive.model.vehicle.vehicle import Vehicle
     from nrel.hive.runner import Environment
-    from nrel.hive.state.simulation_state.simulation_state import (
-        SimulationState,
-    )
+    from nrel.hive.state.simulation_state.simulation_state import SimulationState
 
 
 def refuel_search_event(vehicle: Vehicle, sim: SimulationState, env: Environment) -> Report:
@@ -33,8 +31,8 @@ def refuel_search_event(vehicle: Vehicle, sim: SimulationState, env: Environment
             "vehicle_id": vehicle.id,
             "vehicle_state": vehicle.vehicle_state.__class__.__name__,
             "vehicle_memberships": vehicle.membership.to_json(),
-            "sim_time_start": sim.sim_time,
-            "sim_time_end": next_sim_time,
+            "sim_time_start": str(sim.sim_time),
+            "sim_time_end": str(next_sim_time),
             "lat": lat,
             "lon": lon,
             "geoid": vehicle.geoid,
