@@ -6,9 +6,7 @@ from typing import NamedTuple, TYPE_CHECKING
 if TYPE_CHECKING:
     from nrel.hive.state.simulation_state.update.update import Update
     from nrel.hive.runner.environment import Environment
-    from nrel.hive.state.simulation_state.simulation_state import (
-        SimulationState,
-    )
+    from nrel.hive.state.simulation_state.simulation_state import SimulationState
 
 
 class RunnerPayload(NamedTuple):
