@@ -2,4 +2,4 @@ from typing import TypeVar, Tuple, Optional
 
 T = TypeVar("T")
 
-ErrorOr = Tuple[Optional[Exception], T]
+ErrorOr = Tuple[Optional[Exception], Optional[T]]
