@@ -1,9 +1,7 @@
 from unittest import TestCase
 
 from nrel.hive.state.entity_state import entity_state_ops
-from nrel.hive.state.simulation_state.update.step_simulation import (
-    perform_vehicle_state_updates,
-)
+from nrel.hive.state.simulation_state.update.step_simulation import perform_vehicle_state_updates
 from nrel.hive.state.vehicle_state.out_of_service import OutOfService
 from nrel.hive.state.vehicle_state.servicing_trip import ServicingTrip
 from nrel.hive.resources.mock_lobster import *
